Module refget

Module refget 

Refget integration for enriching unknown contigs with metadata from a refget server.

After matching, contigs that don’t match any known reference can be queried against a refget server (e.g., EBI’s ENA CRAM server) to retrieve aliases and other metadata. This helps users identify what unknown contigs actually are.

Modules

enrichment
Async enrichment logic for querying refget servers about unknown contigs.

Structs

EnrichedContig
A contig enriched with optional refget metadata.
RefgetAlias
A naming-authority alias for a sequence, as returned by refget.
RefgetConfig
Configuration for refget server lookups.

Enums

RefgetLookupResult
Result of looking up a single contig in refget.

Constants

DEFAULT_REFGET_SERVER
Default refget server URL (EBI’s ENA CRAM refget endpoint).