IdentifyArgs

Struct IdentifyArgs 

pub struct IdentifyArgs {
    pub input: PathBuf,
    pub input_format: Option<InputFormat>,
    pub max_matches: usize,
    pub exact_only: bool,
    pub catalog: Option<PathBuf>,
    pub hierarchical: bool,
    pub missing_contig_handling: MissingContigHandling,
    pub weight_match: u32,
    pub weight_coverage: u32,
    pub weight_order: u32,
    pub refget_server: Option<String>,
}

Fields

input: PathBuf

Input file (BAM, SAM, CRAM, FASTA, FAI, VCF, .dict, TSV, or CSV) Use ‘-’ for stdin (expects header text)

input_format: Option<InputFormat>

Input format (auto-detected by default)

max_matches: usize

Number of matches to show

exact_only: bool

Only show exact or near-exact matches

catalog: Option<PathBuf>

Path to custom catalog file

hierarchical: bool

Use hierarchical catalog format (required when –catalog points to a hierarchical catalog)

missing_contig_handling: MissingContigHandling

How to handle references with contigs missing from FASTA (e.g., CHM13 MT which uses standard rCRS mitochondria)

weight_match: u32

Weight for contig match score (0-100, default 70) How well query contigs match reference contigs

weight_coverage: u32

Weight for coverage score (0-100, default 20) What fraction of reference contigs are covered by query

weight_order: u32

Weight for order score (0-100, default 10) Whether contigs appear in the same order

refget_server: Option<String>

Refget server URL for looking up unknown contigs. When set, unmatched contigs with MD5 digests are queried against this server to retrieve aliases and other metadata.