pub fn create_router(refget_config: Option<RefgetConfig>) -> Result<Router>Expand description
Create the application router with all routes and middleware configured.
Pass None for refget_config to disable refget enrichment.
Errors
Returns an error if the catalog cannot be loaded.